@@ -186,7 +186,7 @@ class TelegramNotifier:
         """
 
         session = Session()
-        chat_ids = self._real_init(Session(), config)
+        chat_ids = self._real_init(session, config)
 
         if not chat_ids:
             return
