@@ -1,16 +1,3 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from past.builtins import basestring
-
-import argparse
-import functools
-import logging
-
-from flexget import options
-from flexget.event import event
-
-log = logging.getLogger('cli_config')
-
 """
 Allows specifying yml configuration values from commandline parameters.
 
@@ -29,11 +16,20 @@ Commandline example::
   --cli-config url=http://some.url/ path=~/downloads
 
 """
+import argparse
+import functools
+
+from loguru import logger
+
+from flexget import options
+from flexget.event import event
+
+logger = logger.bind(name='cli_config')
 
 
 def replace_in_item(replaces, item):
     replace = functools.partial(replace_in_item, replaces)
-    if isinstance(item, basestring):
+    if isinstance(item, str):
         # Do replacement in text objects
         for key, val in replaces.items():
             item = item.replace('$%s' % key, val)
@@ -64,5 +60,10 @@ def key_value_pair(text):
 
 @event('options.register')
 def register_parser_arguments():
-    options.get_parser('execute').add_argument('--cli-config', nargs='+', type=key_value_pair, metavar='VARIABLE=VALUE',
-                                               help='configuration parameters through commandline')
+    options.get_parser('execute').add_argument(
+        '--cli-config',
+        nargs='+',
+        type=key_value_pair,
+        metavar='VARIABLE=VALUE',
+        help='configuration parameters through commandline',
+    )
