@@ -1,23 +1,19 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from future.moves import builtins
-
-import logging
 import datetime
 from copy import copy
 
 from jinja2 import UndefinedError
+from loguru import logger
 
 from flexget import plugin
+from flexget.entry import Entry
 from flexget.event import event
 from flexget.task import Task
-from flexget.entry import Entry
 from flexget.utils.template import evaluate_expression
 
-log = logging.getLogger('if')
+logger = logger.bind(name='if')
 
 
-class FilterIf(object):
+class FilterIf:
     """Can run actions on entries that satisfy a given condition.
 
     Actions include accept, reject, and fail, as well as the ability to run other filter plugins on the entries."""
@@ -27,12 +23,9 @@ class FilterIf(object):
         'items': {
             'type': 'object',
             'additionalProperties': {
-                'anyOf': [
-                    {'$ref': '/schema/plugins'},
-                    {'enum': ['accept', 'reject', 'fail']}
-                ]
-            }
-        }
+                'anyOf': [{'$ref': '/schema/plugins'}, {'enum': ['accept', 'reject', 'fail']}]
+            },
+        },
     }
 
     def check_condition(self, condition, entry):
@@ -40,22 +33,26 @@ class FilterIf(object):
         # Make entry fields and other utilities available in the eval namespace
         # We need our namespace to be an Entry instance for lazy loading to work
         eval_locals = copy(entry)
-        eval_locals.update({'has_field': lambda f: f in entry,
-                            'timedelta': datetime.timedelta,
-                            'utcnow': datetime.datetime.utcnow(),
-                            'now': datetime.datetime.now()})
+        eval_locals.update(
+            {
+                'has_field': lambda f: f in entry,
+                'timedelta': datetime.timedelta,
+                'utcnow': datetime.datetime.utcnow(),
+                'now': datetime.datetime.now(),
+            }
+        )
         try:
             # Restrict eval namespace to have no globals and locals only from eval_locals
             passed = evaluate_expression(condition, eval_locals)
             if passed:
-                log.debug('%s matched requirement %s' % (entry['title'], condition))
+                logger.debug('{} matched requirement {}', entry['title'], condition)
             return passed
         except UndefinedError as e:
             # Extract the name that did not exist
             missing_field = e.args[0].split('\'')[1]
-            log.debug('%s does not contain the field %s' % (entry['title'], missing_field))
+            logger.debug('{} does not contain the field {}', entry['title'], missing_field)
         except Exception as e:
-            log.error('Error occurred while evaluating statement `%s`. (%s)' % (condition, e))
+            logger.error('Error occurred while evaluating statement `{}`. ({})', condition, e)
 
     def __getattr__(self, item):
         """Provides handlers for all phases."""
@@ -66,10 +63,7 @@ class FilterIf(object):
             raise AttributeError(item)
 
         def handle_phase(task, config):
-            entry_actions = {
-                'accept': Entry.accept,
-                'reject': Entry.reject,
-                'fail': Entry.fail}
+            entry_actions = {'accept': Entry.accept, 'reject': Entry.reject, 'fail': Entry.fail}
             for item in config:
                 requirement, action = list(item.items())[0]
                 passed_entries = (e for e in task.entries if self.check_condition(requirement, e))
