@@ -1,10 +1,10 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 from datetime import datetime
-import logging
 
-from flexget import plugin, db_schema
+from loguru import logger
+from sqlalchemy import Column, DateTime, String, Unicode
+
+from flexget import db_schema, plugin
+from flexget.components.sites.utils import normalize_unicode
 from flexget.config_schema import one_or_more
 from flexget.entry import Entry
 from flexget.event import event
@@ -12,14 +12,10 @@ from flexget.manager import Session
 from flexget.plugin import PluginError
 from flexget.utils.database import json_synonym
 from flexget.utils.requests import TokenBucketLimiter
-from flexget.utils.search import normalize_unicode
 from flexget.utils.tools import parse_filesize
 
-from sqlalchemy import Column, Unicode, String, DateTime
-
-
-DETECT_2FA = ("Authenticator Code", "TOTP code")
-log = logging.getLogger('gazelle')
+DETECT_2FA = "Authenticator Code", "TOTP code"
+logger = logger.bind(name='gazelle')
 Base = db_schema.versioned_base('gazelle_session', 0)
 
 
@@ -36,7 +32,7 @@ class GazelleSession(Base):
     expires = Column(DateTime)
 
 
-class InputGazelle(object):
+class InputGazelle:
     """A generic plugin that searches a Gazelle-based website
 
     Limited functionality but should work for almost all of them.
@@ -48,18 +44,14 @@ class InputGazelle(object):
 
         # Aliases for config -> api params
         # Extended in subclasses
-        self.aliases = {
-            "search": "searchstr"
-        }
+        self.aliases = {"search": "searchstr"}
 
         # API parameters
         # None means a raw value entry (no validation other than schema)
         # A dict means an enum with a config -> api mapping
         # A list is an enum with no mapping
         # Extended in subclasses
-        self.params = {
-            "searchstr": None
-        }
+        self.params = {"searchstr": None}
 
     @property
     def schema(self):
@@ -77,7 +69,7 @@ class InputGazelle(object):
                 'search': {'type': 'string'},
             },
             'required': ['username', 'password'],
-            'additionalProperties': False
+            'additionalProperties': False,
         }
         # base_url is only required if the subclass doesn't set it
         if not self.base_url:
@@ -122,7 +114,11 @@ class InputGazelle(object):
         base_url = config.get('base_url', "").rstrip("/")
         if base_url:
             if self.base_url and self.base_url != base_url:
-                log.warning("Using plugin designed for %s on %s - things may break", self.base_url, base_url)
+                logger.warning(
+                    'Using plugin designed for {} on {} - things may break',
+                    self.base_url,
+                    base_url,
+                )
             self.base_url = base_url
 
         if not self.base_url:
@@ -149,12 +145,16 @@ class InputGazelle(object):
 
         Return True on successful recovery, False otherwise
         """
-        log.debug("Attempting to find an existing session in the DB")
+        logger.debug("Attempting to find an existing session in the DB")
         with Session() as session:
-            db_session = session.query(GazelleSession).filter(
-                GazelleSession.base_url == self.base_url,
-                GazelleSession.username == self.username
-            ).one_or_none()
+            db_session = (
+                session.query(GazelleSession)
+                .filter(
+                    GazelleSession.base_url == self.base_url,
+                    GazelleSession.username == self.username,
+                )
+                .one_or_none()
+            )
             if db_session and db_session.expires and db_session.expires >= datetime.utcnow():
                 # Found a valid session in the DB - use it
                 self._session.cookies.update(db_session.cookies)
@@ -165,17 +165,20 @@ class InputGazelle(object):
 
     def save_current_session(self):
         """Store the current session in the database so it can be resumed later"""
-        log.debug("Storing session info in the DB")
+        logger.debug("Storing session info in the DB")
         with Session() as session:
             expires = None
             for c in self._session.cookies:
                 if c.name == "session":
                     expires = datetime.utcfromtimestamp(c.expires)
-            db_session = GazelleSession(username=self.username,
-                                        base_url=self.base_url,
-                                        cookies=dict(self._session.cookies),
-                                        expires=expires, authkey=self.authkey,
-                                        passkey=self.passkey)
+            db_session = GazelleSession(
+                username=self.username,
+                base_url=self.base_url,
+                cookies=dict(self._session.cookies),
+                expires=expires,
+                authkey=self.authkey,
+                passkey=self.passkey,
+            )
             session.merge(db_session)
 
     def authenticate(self, force=False):
@@ -187,16 +190,12 @@ class InputGazelle(object):
         self._session.cookies.clear()
 
         if not force and self.resume_session():
-            log.info("Logged into %s using cached session", self.base_url)
+            logger.info('Logged into {} using cached session', self.base_url)
             return
 
         # Forcing a re-login or no session in DB - log in using provided creds
         url = "{}/login.php".format(self.base_url)
-        data = {
-            'username': self.username,
-            'password': self.password,
-            'keeplogged': 1,
-        }
+        data = {'username': self.username, 'password': self.password, 'keeplogged': 1}
         r = self._session.post(url, data=data, allow_redirects=False, raise_status=True)
         if not r.is_redirect or r.next.url != "{}/index.php".format(self.base_url):
             msg = "Failed to log into {}".format(self.base_url)
@@ -210,7 +209,7 @@ class InputGazelle(object):
         account_info = self.request(no_login=True, action='index')
         self.authkey = account_info['authkey']
         self.passkey = account_info['passkey']
-        log.info("Logged in to %s", self.base_url)
+        logger.info('Logged in to {}', self.base_url)
 
         # Store the session so we can resume it later
         self.save_current_session()
@@ -229,7 +228,7 @@ class InputGazelle(object):
         ajaxpage = "{}/ajax.php".format(self.base_url)
         r = self._session.get(ajaxpage, params=params, allow_redirects=False, raise_status=True)
         if not no_login and r.is_redirect and r.next.url == "{}/login.php".format(self.base_url):
-            log.warning("Redirected to login page, reauthenticating and trying again")
+            logger.warning("Redirected to login page, reauthenticating and trying again")
             self.authenticate(force=True)
             return self.request(no_login=True, **params)
 
@@ -245,7 +244,9 @@ class InputGazelle(object):
                 if not error or error == "failure":
                     error = json_response.get('response', str(json_response))
 
-                raise PluginError("{} gave a failure response of '{}'".format(self.base_url, error))
+                raise PluginError(
+                    "{} gave a failure response of '{}'".format(self.base_url, error)
+                )
             return json_response['response']
         except (ValueError, TypeError, KeyError):
             raise PluginError("{} returned an invalid response".format(self.base_url))
@@ -258,7 +259,7 @@ class InputGazelle(object):
             if pages and page >= pages:
                 break
 
-            log.debug("Attempting to get page %d of search results", page)
+            logger.debug('Attempting to get page {} of search results', page)
             result = self.request(action='browse', page=page, **params)
             if not result['results']:
                 break
@@ -269,7 +270,7 @@ class InputGazelle(object):
             page += 1
 
         if page > self.max_pages:
-            log.warning("Stopped after %d pages (out of %d total pages)", self.max_pages, pages)
+            logger.warning('Stopped after {} pages (out of {} total pages)', self.max_pages, pages)
 
     def get_entries(self, search_results):
         """Generator that yields Entry objects from search results"""
@@ -285,14 +286,14 @@ class InputGazelle(object):
                 yield Entry(
                     title="{groupName} ({groupId} - {torrentId}).torrent".format(**temp),
                     url="{}/torrents.php?action=download&id={}&authkey={}&torrent_pass={}"
-                        "".format(self.base_url, temp['torrentId'], self.authkey, self.passkey),
+                    "".format(self.base_url, temp['torrentId'], self.authkey, self.passkey),
                     torrent_seeds=tor['seeders'],
                     torrent_leeches=tor['leechers'],
                     # Size is returned in bytes
-                    content_size=parse_filesize(str(tor['size']) + "b")
+                    content_size=parse_filesize(str(tor['size']) + "b"),
                 )
 
-    @plugin.internet(log)
+    @plugin.internet(logger)
     def search(self, task, entry, config):
         """Search interface"""
         self.setup(task, config)
@@ -305,13 +306,13 @@ class InputGazelle(object):
             entries.update(self.get_entries(self.search_results(params)))
         return entries
 
-    @plugin.internet(log)
+    @plugin.internet(logger)
     def on_task_input(self, task, config):
         """Task input interface"""
         self.setup(task, config)
 
         params = self.params_from_config(config)
-        return list(self.get_entries(self.search_results(params)))
+        return self.get_entries(self.search_results(params))
 
 
 class InputGazelleMusic(InputGazelle):
@@ -323,76 +324,64 @@ class InputGazelleMusic(InputGazelle):
 
     def __init__(self):
         """Set up the majority of parameters that these sites support"""
-        super(InputGazelleMusic, self).__init__()
+        super().__init__()
 
-        self.aliases.update({
-            "artist": "artistname",
-            "album": "groupname",
-            "leech_type": "freetorrent",
-            "release_type": "releasetype",
-            "tags": "taglist",
-            "tag_type": "tags_type",
-            "log": "haslog",
-        })
-
-        self.params.update({
-            "taglist": None,
-            "artistname": None,
-            "groupname": None,
-            "year": None,
-            "tags_type": {
-                "any": 0,
-                "all": 1,
-            },
-            "encoding": [
-                "192", "APS (VBR)", "V2 (VBR)", "V1 (VBR)", "256", "APX (VBR)",
-                "V0 (VBR)", "q8.x (VBR)", "320", "Lossless", "24bit Lossless", "Other"
-            ],
-            "format": [
-                "MP3", "FLAC", "Ogg Vorbis", "AAC", "AC3", "DTS"
-            ],
-            "media": [
-                "CD", "DVD", "Vinyl", "Soundboard", "SACD", "DAT", "Cassette", "WEB"
-            ],
-            "releasetype": {
-                "album": 1,
-                "soundtrack": 3,
-                "EP": 5,
-                "anthology": 6,
-                "compilation": 7,
-                "single": 9,
-                "live album": 11,
-                "remix": 13,
-                "bootleg": 14,
-                "interview": 15,
-                "mixtape": 16,
-                "unknown": 21,
-            },
-            "haslog": {
-                "False": 0,
-                "True": 1,
-                "100%": 100,
-                "<100%": -1
-            },
-            "freetorrent": {
-                "freeleech": 1,
-                "neutral": 2,
-                "either": 3,
-                "normal": 0,
-            },
-            "hascue": {
-                "False": 0,
-                "True": 1,
-            },
-            "scene": {
-                "False": 0,
-                "True": 1,
-            },
-            "vanityhouse": {
-                "False": 0,
-                "True": 1,
+        self.aliases.update(
+            {
+                "artist": "artistname",
+                "album": "groupname",
+                "leech_type": "freetorrent",
+                "release_type": "releasetype",
+                "tags": "taglist",
+                "tag_type": "tags_type",
+                "log": "haslog",
             }
-        })
+        )
+
+        self.params.update(
+            {
+                "taglist": None,
+                "artistname": None,
+                "groupname": None,
+                "year": None,
+                "tags_type": {"any": 0, "all": 1},
+                "encoding": [
+                    "192",
+                    "APS (VBR)",
+                    "V2 (VBR)",
+                    "V1 (VBR)",
+                    "256",
+                    "APX (VBR)",
+                    "V0 (VBR)",
+                    "q8.x (VBR)",
+                    "320",
+                    "Lossless",
+                    "24bit Lossless",
+                    "Other",
+                ],
+                "format": ["MP3", "FLAC", "Ogg Vorbis", "AAC", "AC3", "DTS"],
+                "media": ["CD", "DVD", "Vinyl", "Soundboard", "SACD", "DAT", "Cassette", "WEB"],
+                "releasetype": {
+                    "album": 1,
+                    "soundtrack": 3,
+                    "EP": 5,
+                    "anthology": 6,
+                    "compilation": 7,
+                    "single": 9,
+                    "live album": 11,
+                    "remix": 13,
+                    "bootleg": 14,
+                    "interview": 15,
+                    "mixtape": 16,
+                    "unknown": 21,
+                },
+                "haslog": {"False": 0, "True": 1, "100%": 100, "<100%": -1},
+                "freetorrent": {"freeleech": 1, "neutral": 2, "either": 3, "normal": 0},
+                "hascue": {"False": 0, "True": 1},
+                "scene": {"False": 0, "True": 1},
+                "vanityhouse": {"False": 0, "True": 1},
+            }
+        )
 
     @property
     def schema(self):
@@ -400,23 +389,33 @@ class InputGazelleMusic(InputGazelle):
 
         Extends the super's schema
         """
-        schema = super(InputGazelleMusic, self).schema
-        schema['properties'].update({
-            'artist': {'type': 'string'},
-            'album': {'type': 'string'},
-            'year': {'type': ['string', 'integer']},
-            'tags': one_or_more({'type': 'string'}),
-            'tag_type': {'type': 'string', 'enum': list(self._opts('tag_type').keys())},
-            'encoding': {'type': 'string', 'enum': self._opts('encoding')},
-            'format': {'type': 'string', 'enum': self._opts('format')},
-            'media': {'type': 'string', 'enum': self._opts('media')},
-            'release_type': {'type': 'string', 'enum': list(self._opts('release_type').keys())},
-            'log': {'oneOf': [{'type': 'string', 'enum': list(self._opts('log').keys())}, {'type': 'boolean'}]},
-            'leech_type': {'type': 'string', 'enum': list(self._opts('leech_type').keys())},
-            'hascue': {'type': 'boolean'},
-            'scene': {'type': 'boolean'},
-            'vanityhouse': {'type': 'boolean'}
-        })
+        schema = super().schema
+        schema['properties'].update(
+            {
+                'artist': {'type': 'string'},
+                'album': {'type': 'string'},
+                'year': {'type': ['string', 'integer']},
+                'tags': one_or_more({'type': 'string'}),
+                'tag_type': {'type': 'string', 'enum': list(self._opts('tag_type').keys())},
+                'encoding': {'type': 'string', 'enum': self._opts('encoding')},
+                'format': {'type': 'string', 'enum': self._opts('format')},
+                'media': {'type': 'string', 'enum': self._opts('media')},
+                'release_type': {
+                    'type': 'string',
+                    'enum': list(self._opts('release_type').keys()),
+                },
+                'log': {
+                    'oneOf': [
+                        {'type': 'string', 'enum': list(self._opts('log').keys())},
+                        {'type': 'boolean'},
+                    ]
+                },
+                'leech_type': {'type': 'string', 'enum': list(self._opts('leech_type').keys())},
+                'hascue': {'type': 'boolean'},
+                'scene': {'type': 'boolean'},
+                'vanityhouse': {'type': 'boolean'},
+            }
+        )
         return schema
 
     def get_entries(self, search_results):
@@ -428,17 +427,19 @@ class InputGazelleMusic(InputGazelle):
             # Releases can have multiple download options
             for tor in result['torrents']:
                 temp = info.copy()
-                temp.update(dict((k, tor[k]) for k in ('media', 'encoding', 'format', 'torrentId')))
+                temp.update(
+                    dict((k, tor[k]) for k in ('media', 'encoding', 'format', 'torrentId'))
+                )
 
                 yield Entry(
                     title="{artist} - {groupName} - {groupYear} "
-                          "({media} - {format} - {encoding})-{torrentId}.torrent".format(**temp),
+                    "({media} - {format} - {encoding})-{torrentId}.torrent".format(**temp),
                     url="{}/torrents.php?action=download&id={}&authkey={}&torrent_pass={}"
-                        "".format(self.base_url, temp['torrentId'], self.authkey, self.passkey),
+                    "".format(self.base_url, temp['torrentId'], self.authkey, self.passkey),
                     torrent_seeds=tor['seeders'],
                     torrent_leeches=tor['leechers'],
                     # Size is returned in bytes
-                    content_size=parse_filesize(str(tor['size']) + "b")
+                    content_size=parse_filesize(str(tor['size']) + "b"),
                 )
 
 
@@ -447,17 +448,13 @@ class InputRedacted(InputGazelleMusic):
 
     def __init__(self):
         """Set up custom base_url and parameters"""
-        super(InputRedacted, self).__init__()
+        super().__init__()
         self.base_url = "https://redacted.ch"
 
         self.params['encoding'].remove("q8.x (VBR)")
         self.params['format'].remove("Ogg Vorbis")
         self.params['media'].append("Blu-ray")
-        self.params['releasetype'].update({
-            "demo": 17,
-            "concert recording": 18,
-            "dj mix": 19,
-        })
+        self.params['releasetype'].update({"demo": 17, "concert recording": 18, "dj mix": 19})
 
 
 class InputNotWhat(InputGazelleMusic):
@@ -465,26 +462,24 @@ class InputNotWhat(InputGazelleMusic):
 
     def __init__(self):
         """Set up custom base_url and parameters"""
-        super(InputNotWhat, self).__init__()
+        super().__init__()
         self.base_url = "https://notwhat.cd"
 
         self.params['media'].extend(['Blu-ray', 'Unknown'])
-        self.params['releasetype'].update({
-            'demo': 22,
-            'dj mix': 23,
-            'concert recording': 24
-        })
-        self.params['haslog'].update({
-            "gold": 102,
-            "silver": 101,
-            "gold/silver": 100,
-            "lineage": -5,
-            "unscored": -1,
-            "missing lineage": -6,
-            "missing dr score": -7,
-            "missing sample rate": -8,
-            "missing description": -9
-        })
+        self.params['releasetype'].update({'demo': 22, 'dj mix': 23, 'concert recording': 24})
+        self.params['haslog'].update(
+            {
+                "gold": 102,
+                "silver": 101,
+                "gold/silver": 100,
+                "lineage": -5,
+                "unscored": -1,
+                "missing lineage": -6,
+                "missing dr score": -7,
+                "missing sample rate": -8,
+                "missing description": -9,
+            }
+        )
 
 
 @event('plugin.register')
