@@ -161,7 +161,7 @@ _color_ranges = [
     QualityComponent('color_range', 20, '10bit', r'10[^\w]?bits?|hi10p?'),
     QualityComponent('color_range', 40, 'hdrplus', r'hdr[^\w]?(\+|p|plus)'),
     QualityComponent('color_range', 30, 'hdr', r'hdr([^\w]?10)?'),
-    QualityComponent('color_range', 50, 'dolbyvision', r'(dolby[^\w]?vision|dv)'),
+    QualityComponent('color_range', 50, 'dolbyvision', r'(dolby[^\w]?vision|dv|dovi)'),
 ]
 
 channels = r'(?:(?:[^\w+]?[1-7][\W_]?(?:0|1|ch)))'
